Index: mojo/system/dispatcher.h |
diff --git a/mojo/system/dispatcher.h b/mojo/system/dispatcher.h |
index c6ef75298de5344808318c424f09a20e7f44eaa2..75d9d42e0f674db3c71eac636323cbf7990cc2fe 100644 |
--- a/mojo/system/dispatcher.h |
+++ b/mojo/system/dispatcher.h |
@@ -27,6 +27,7 @@ class Channel; |
class CoreImpl; |
class Dispatcher; |
class DispatcherTransport; |
+class HandleTable; |
class LocalMessagePipeEndpoint; |
class MessageInTransit; |
class ProxyMessagePipeEndpoint; |
@@ -126,16 +127,17 @@ class MOJO_SYSTEM_IMPL_EXPORT Dispatcher : |
void RemoveWaiter(Waiter* waiter); |
// A dispatcher must be put into a special state in order to be sent across a |
// message pipe. Outside of tests, only |CoreImplAccess| is allowed to do |
// this, since there are requirements on the handle table (see below). |
// |
// In this special state, only a restricted set of operations is allowed. |
// These are the ones available as |DispatcherTransport| methods. Other |
// |Dispatcher| methods must not be called until |DispatcherTransport::End()| |
// has been called. |
- class CoreImplAccess { |
+ class HandleTableAccess { |
private: |
friend class CoreImpl; |
+ friend class HandleTable; |
// Tests also need this, to avoid needing |CoreImpl|. |
friend DispatcherTransport test::DispatcherTryStartTransport(Dispatcher*); |
@@ -300,8 +302,8 @@ class MOJO_SYSTEM_IMPL_EXPORT Dispatcher : |
}; |
// Wrapper around a |Dispatcher| pointer, while it's being processed to be |
// passed in a message pipe. See the comment about |Dispatcher::CoreImplAccess| |
// for more details. |
// |
// Note: This class is deliberately "thin" -- no more expensive than a |
// |Dispatcher*|. |
@@ -324,7 +326,7 @@ class MOJO_SYSTEM_IMPL_EXPORT DispatcherTransport { |
Dispatcher* dispatcher() { return dispatcher_; } |
private: |
- friend class Dispatcher::CoreImplAccess; |
+ friend class Dispatcher::HandleTableAccess; |
explicit DispatcherTransport(Dispatcher* dispatcher) |
: dispatcher_(dispatcher) {} |
@@ -126,16 +127,17 @@ class MOJO_SYSTEM_IMPL_EXPORT Dispatcher : |
void RemoveWaiter(Waiter* waiter); |
// A dispatcher must be put into a special state in order to be sent across a |
- // message pipe. Outside of tests, only |CoreImplAccess| is allowed to do |
+ // message pipe. Outside of tests, only |HandleTableAccess| is allowed to do |
// this, since there are requirements on the handle table (see below). |
// |
@@ -300,8 +302,8 @@ class MOJO_SYSTEM_IMPL_EXPORT Dispatcher : |
}; |
// Wrapper around a |Dispatcher| pointer, while it's being processed to be |
-// passed in a message pipe. See the comment about |Dispatcher::CoreImplAccess| |
-// for more details. |
+// passed in a message pipe. See the comment about |
+// |Dispatcher::HandleTableAccess| for more details. |
// |
// Note: This class is deliberately "thin" -- no more expensive than a |